@@ -1,5 +1,5 @@
 /* Keyboard Accessibility Status Applet
- * Copyright 2003 Sun Microsystems Inc.
+ * Copyright 2003, 2004 Sun Microsystems Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -19,16 +19,14 @@
 
 #include <config.h>
 #include <panel-applet-gconf.h>
-#if HAVE_EGG
+
 #include <egg-screen-help.h>
-#else
-#include <libgnome/gnome-help.h>
-#endif
 #include <glib-object.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkx.h>
 #include <X11/XKBlib.h>
 #define XK_MISCELLANY
+#define XK_XKB_KEYS
 #include <X11/keysymdef.h>
 #include "applet.h"
 
@@ -136,6 +134,9 @@ about_cb (BonoboUIComponent          *uic,
 	const gchar *translator_credits = _("translator_credits");
 
 	if (sapplet->about_dialog) {
+		gtk_window_set_screen (GTK_WINDOW (sapplet->about_dialog),
+				       gtk_widget_get_screen (GTK_WIDGET (sapplet->applet)));
+
 		gtk_window_present (GTK_WINDOW (sapplet->about_dialog));
 		return;
 	}
@@ -177,16 +178,13 @@ help_cb (BonoboUIComponent   *uic,
 	 const char          *verbname)
 {
 	GError *error = NULL;
-#if HAVE_EGG
+
 	egg_help_display_on_screen (
-		"accessx-help.xml", NULL,
+		"accessx-status.xml", NULL,
 		gtk_widget_get_screen (GTK_WIDGET (sapplet->applet)),
 		&error);
+
 	if (error) { 
-#else 
-	gboolean retval = gnome_help_display ("accessx-status.xml", NULL, &error);
-	if (!retval) {
-#endif
 		GtkWidget *dialog = 
 			gtk_message_dialog_new (GTK_WINDOW (sapplet->applet),
 						GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -194,10 +192,15 @@ help_cb (BonoboUIComponent   *uic,
 						GTK_BUTTONS_CLOSE,
 						_("There was an error launching the help viewer : %s"), 
 						error->message);
+
 		g_signal_connect (G_OBJECT (dialog),
 				  "response",
 				  G_CALLBACK (gtk_widget_destroy), NULL);
+
+		gtk_window_set_screen (GTK_WINDOW (dialog),
+				       gtk_widget_get_screen (GTK_WIDGET (sapplet->applet)));
 		gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+		
 		gtk_widget_show (dialog);
 		g_error_free (error);
 	}
@@ -208,30 +211,42 @@ dialog_cb (BonoboUIComponent *component,
 	   AccessxStatusApplet *sapplet,
 	   const char        *verb)
 {
-	GError *err = NULL;
-	if (!g_spawn_command_line_async ("gnome-accessibility-keyboard-properties", &err)) {
+	GError *error = NULL;
+	int ret;
+
+
+
+	gdk_spawn_command_line_on_screen (gtk_widget_get_screen (GTK_WIDGET (sapplet->applet)),
+			"gnome-accessibility-keyboard-properties", &error);
+
+	if (error != NULL) {
 		GtkWidget *dialog = 
 			gtk_message_dialog_new (NULL,
 						GTK_DIALOG_DESTROY_WITH_PARENT,
 						GTK_MESSAGE_ERROR,
 						GTK_BUTTONS_CLOSE,
 						_("There was an error launching the keyboard capplet : %s"), 
-						err->message);
+						error->message);
+
 		g_signal_connect (G_OBJECT (dialog),
 				  "response",
 				  G_CALLBACK (gtk_widget_destroy), NULL);
+
+		gtk_window_set_screen (GTK_WINDOW (dialog),
+				       gtk_widget_get_screen (GTK_WIDGET (sapplet->applet)));
 		gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+
 		gtk_widget_show (dialog);
-		g_error_free (err);
+		g_error_free (error);
 	}
 }
 
 static const BonoboUIVerb accessx_status_applet_menu_verbs [] = {
-        BONOBO_UI_UNSAFE_VERB ("Dialog", dialog_cb),
-        BONOBO_UI_UNSAFE_VERB ("Help", help_cb),
-        BONOBO_UI_UNSAFE_VERB ("About", about_cb),
+	BONOBO_UI_UNSAFE_VERB ("Dialog", dialog_cb),
+	BONOBO_UI_UNSAFE_VERB ("Help", help_cb),
+	BONOBO_UI_UNSAFE_VERB ("About", about_cb),
 
-        BONOBO_UI_VERB_END
+	BONOBO_UI_VERB_END
 };
 
 XkbDescPtr 
@@ -248,14 +263,14 @@ accessx_status_applet_get_xkb_desc (AccessxStatusApplet *sapplet)
 					  &reason_return);
 		g_assert (display); /* TODO: change error message below to something user-viewable */
 		if (display == NULL)
-		        g_warning ("Xkb extension could not be initialized! (error code %x)", reason_return);
+			g_warning ("Xkb extension could not be initialized! (error code %x)", reason_return);
 		else 
 			sapplet->xkb = XkbGetMap (display, 
 						  XkbAllComponentsMask,
 						  XkbUseCoreKbd);
 		g_assert (sapplet->xkb);
 		if (sapplet->xkb == NULL)
-		        g_warning ("Xkb keyboard description not available!");
+			g_warning ("Xkb keyboard description not available!");
 		sapplet->xkb_display = display;
 	}
 	return sapplet->xkb;
@@ -300,8 +315,11 @@ accessx_status_applet_init_modifiers (AccessxStatusApplet *sapplet)
 	super_mask = XkbKeysymToModifiers (sapplet->xkb_display, XK_Super_L);
 	if (super_mask) gtk_widget_show (sapplet->super_indicator);
 	else gtk_widget_hide (sapplet->super_indicator);
+	alt_gr_mask = XkbKeysymToModifiers (sapplet->xkb_display, XK_Mode_switch) | 
+	    XkbKeysymToModifiers (sapplet->xkb_display, XK_ISO_Level3_Shift) |
+	    XkbKeysymToModifiers (sapplet->xkb_display, XK_ISO_Level3_Latch) | 
+	    XkbKeysymToModifiers (sapplet->xkb_display, XK_ISO_Level3_Lock);
 
-	alt_gr_mask = XkbKeysymToModifiers (sapplet->xkb_display, XK_Mode_switch);
 	if (alt_gr_mask) gtk_widget_show (sapplet->alt_graph_indicator);
 	else gtk_widget_hide (sapplet->alt_graph_indicator);
 
@@ -318,7 +336,6 @@ accessx_status_applet_init_modifiers (AccessxStatusApplet *sapplet)
 			modifiers[i].indicator = sapplet->hyper_indicator;
 		else if (modifiers[i].mask == super_mask)
 			modifiers[i].indicator = sapplet->super_indicator;
-		/* due to some XKB/XFree weirdness, AltGr doesn't give notifications */
 		else if (modifiers[i].mask == alt_gr_mask)
 			modifiers[i].indicator = sapplet->alt_graph_indicator;
 	}
@@ -384,10 +401,9 @@ accessx_status_applet_get_glyph_pixbuf (AccessxStatusApplet *sapplet,
 	cmap = gdk_drawable_get_colormap (GDK_DRAWABLE (pixmap));
 	if (!cmap) cmap = gdk_colormap_new (visual, FALSE);
 	else g_object_ref (cmap);
-	gdk_color_white (cmap, &white);
 	gdk_colormap_alloc_color (cmap, fg, FALSE, TRUE);
 	gdk_colormap_alloc_color (cmap, bg, FALSE, TRUE);
-	gdk_gc_set_foreground (gc, &white);
+	gdk_gc_set_foreground (gc, bg);
 	gdk_draw_rectangle (pixmap, gc, True, 0, 0, w, h);
 	gdk_gc_set_foreground (gc, fg);
 	gdk_gc_set_background (gc, bg);
@@ -402,7 +418,7 @@ accessx_status_applet_get_glyph_pixbuf (AccessxStatusApplet *sapplet,
 	glyph_pixbuf = gdk_pixbuf_get_from_drawable (NULL, pixmap, 
 						     cmap, 0, 0, 0, 0, w, h);
 	gdk_pixmap_unref (pixmap);
-	alpha_pixbuf = gdk_pixbuf_add_alpha (glyph_pixbuf, TRUE, 255, 255, 255);
+	alpha_pixbuf = gdk_pixbuf_add_alpha (glyph_pixbuf, TRUE, bg->red >> 8, bg->green >> 8, bg->blue >> 8);
 	g_object_unref (G_OBJECT (glyph_pixbuf));
 	g_object_unref (G_OBJECT (cmap));
 	g_object_unref (G_OBJECT (gc));
@@ -802,6 +818,7 @@ accessx_status_applet_altgraph_icon_set (AccessxStatusApplet *sapplet, GtkWidget
 	GtkStyle    *style = gtk_widget_get_style (widget);
 	GdkPixbuf   *icon_base;
 
+	gtk_widget_set_sensitive (widget, TRUE);
 	for (i = 0; i < 3; ++i) {
 		int alpha;
 		GdkColor *fg, *bg;
@@ -813,38 +830,42 @@ accessx_status_applet_altgraph_icon_set (AccessxStatusApplet *sapplet, GtkWidget
 		switch (states[i]) {
 		case GTK_STATE_NORMAL:
 			alpha = 255;
+			gtk_widget_set_sensitive (widget, TRUE);
 			gtk_widget_set_state (widget, GTK_STATE_NORMAL);
 			break;
 		case GTK_STATE_SELECTED:
-			/* 
-			 * This is incorrect for theming, but since XKB doesn't generate 
-			 * latch events properly, 
-			 * for AltGr, it doesn't matter...  this state isn't ever used.
-			 */
-			fg = &style->base[states[i]]; /* err, what's that again? */
+		    /* FIXME: should use text/base here, for selected ? */
+			fg = &style->white; 
 			bg = &style->black;
 			alpha = 255;
+			gtk_widget_set_sensitive (widget, TRUE);
 			gtk_widget_set_state (widget, GTK_STATE_SELECTED);
 			break;
 		case GTK_STATE_INSENSITIVE:
 		default:
 			alpha = 63;
 			gtk_widget_set_sensitive (widget, FALSE);
+			wildcarded = TRUE;
 			break;
 		}
 		icon_base = gtk_widget_render_icon (widget,
 			ACCESSX_BASE_ICON, icon_size_spec, NULL);
 		pixbuf = gdk_pixbuf_copy (icon_base);
 		g_object_unref (icon_base);
+	       /* 
+		* should be N_("ae"));
+		* need en_ locale for this.
+		*/
+	       /* 
+		* Translators: substitute an easily-recognized single glyph 
+		* from Level 2, i.e. an AltGraph character from a common keyboard 
+		* in your locale. 
+		*/
 		glyph_pixbuf = accessx_status_applet_get_glyph_pixbuf (sapplet, 
 								       widget,
 								       pixbuf, 
 								       fg, 
 								       bg,
-				       /* 
-					* should be N_("ae"));
-					* need en_ locale for this
-					*/
 								       ("æ"));
 		gdk_pixbuf_composite (glyph_pixbuf, pixbuf, 0, 0, 
 				      gdk_pixbuf_get_width (glyph_pixbuf),
@@ -959,8 +980,8 @@ accessx_status_applet_layout_box (AccessxStatusApplet *sapplet, GtkWidget *box,
 	sapplet->box = box;
 
 	atko = gtk_widget_get_accessible (sapplet->box);
-	atk_object_set_name (atko, "AccessX Status");
-	atk_object_set_description (atko, "Shows keyboard status when accessibility features are used.");
+	atk_object_set_name (atko, _("AccessX Status"));
+	atk_object_set_description (atko, _("Shows keyboard status when accessibility features are used."));
 
 	gtk_widget_show (sapplet->box);
 	gtk_widget_show (GTK_WIDGET (sapplet->applet));
@@ -990,7 +1011,7 @@ create_applet (PanelApplet *applet)
 	AtkObject           *atko;
 	GdkPixbuf	    *pixbuf;
         gint                 large_toolbar_pixels;
-		
+
 	sapplet->xkb = NULL;
 	sapplet->xkb_display = NULL;
 	sapplet->box = NULL;
@@ -1057,8 +1078,8 @@ create_applet (PanelApplet *applet)
 
 	accessx_status_applet_layout_box (sapplet, box, stickyfoo);
 	atko = gtk_widget_get_accessible (GTK_WIDGET (sapplet->applet));
-	atk_object_set_name (atko, "AccessX Status");
-	atk_object_set_description (atko, "Shows keyboard status when accessibility features are used.");
+	atk_object_set_name (atko, _("AccessX Status"));
+	atk_object_set_description (atko, _("Shows keyboard status when accessibility features are used."));
 	return sapplet;
 }
 
@@ -1106,10 +1127,38 @@ accessx_status_applet_resize (GtkWidget *widget, int size, gpointer user_data)
 	; /* TODO: either rescale icons to fit panel, or tile them when possible */
 }
 
+static void
+accessx_status_applet_background (PanelApplet *a, PanelAppletBackgroundType type,
+				  GdkColor *color, GdkPixmap *pixmap, gpointer user_data)
+{
+	AccessxStatusApplet *sapplet = user_data;
+	GtkRcStyle *rc_style = gtk_rc_style_new ();
+
+	switch (type) {
+	case PANEL_PIXMAP_BACKGROUND:
+		gtk_widget_modify_style (GTK_WIDGET (sapplet->applet), rc_style);
+		break;
+
+	case PANEL_COLOR_BACKGROUND:
+		gtk_widget_modify_bg (GTK_WIDGET (sapplet->applet), GTK_STATE_NORMAL, color);
+		break;
+
+	case PANEL_NO_BACKGROUND:
+		gtk_widget_modify_style (GTK_WIDGET (sapplet->applet), rc_style);
+		break;
+
+	default:
+		gtk_widget_modify_style (GTK_WIDGET (sapplet->applet), rc_style);
+		break;
+	}
+
+	gtk_rc_style_unref (rc_style);
+}
+
 static gboolean
 button_press_cb (GtkWidget *widget, GdkEventButton *event, AccessxStatusApplet *sapplet)
 {
-	if (event->button == 1 && event->type == GDK_2BUTTON_PRESS) 
+	if (event->button == 1 && event->type == GDK_BUTTON_PRESS) 
 		dialog_cb (NULL, sapplet, NULL);
 
 	return FALSE;
@@ -1161,6 +1210,7 @@ accessx_status_applet_fill (PanelApplet *applet)
 			  "signal::destroy", accessx_status_applet_destroy, sapplet,
 			  "signal::change_orient", accessx_status_applet_reorient, sapplet,
 			  "signal::change_size", accessx_status_applet_resize, sapplet,
+			  "signal::change_background", accessx_status_applet_background, sapplet,
 			  NULL);
 			  
 	g_signal_connect (sapplet->applet, "button_press_event",
