@@ -18,28 +18,29 @@
  *
  * May, 2000. Implemented on FreeBSD 4.0-RELEASE (Compaq Armada M700)
  *
-$Id: properties.c,v 1.32 2003/12/17 16:33:03 kevinv Exp $
+$Id: properties.c,v 1.34 2004/02/19 00:41:43 kevinv Exp $
  */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
-#include <sys/file.h>
-#include <sys/ioctl.h>
-#include <sys/types.h>
-#include <sys/sysctl.h>
 #include <stdio.h>
 
 #ifdef __FreeBSD__
 #include <machine/apm_bios.h>
-#elif __OpenBSD__
+#elif defined(__NetBSD__) || defined(__OpenBSD__)
 #include <sys/param.h>
 #include <machine/apmvar.h>
 #elif __linux__
 #include <apm.h>
 #endif
 
+#include <sys/file.h>
+#include <sys/ioctl.h>
+#include <sys/types.h>
+#include <sys/sysctl.h>
+
 #include <err.h>
 #include <stdlib.h>
 #include <string.h>
@@ -66,7 +67,7 @@ $Id: properties.c,v 1.32 2003/12/17 16:33:03 kevinv Exp $
 #define gettext_noop(String) (String)
 #endif
 
-#ifdef __OpenBSD__
+#if defined(__NetBSD__) || defined(__OpenBSD__)
 extern struct apm_power_info apminfo;
 #else
 extern struct apm_info apminfo;
@@ -344,7 +345,7 @@ prop_cb (BonoboUIComponent *uic,
 #ifdef __FreeBSD__
   percentage = apminfo.ai_batt_life;
   if(percentage == 255) percentage = 0;
-#elif __OpenBSD__
+#elif defined(__NetBSD__) || defined(__OpenBSD__)
   percentage = apminfo.battery_life;
   if(percentage == 255) percentage = 0;
 #elif __linux__
@@ -482,6 +483,8 @@ prop_cb (BonoboUIComponent *uic,
   g_signal_connect (G_OBJECT(battstat->suspend_entry), "changed",
 		    G_CALLBACK(suspend_changed), battstat);
 
+  g_warning ("%s", battstat->suspend_cmd ? battstat->suspend_cmd : "ARSE");
+  gtk_entry_set_text (GTK_ENTRY (battstat->suspend_entry), battstat->suspend_cmd); 
   if ( ! key_writable (PANEL_APPLET (battstat->applet), "suspend_command") ||
       inhibit_command_line) {
 	  hard_set_sensitive (battstat->suspend_entry, FALSE);
