@@ -371,8 +371,10 @@ start_gtcd_cb (BonoboUIComponent *component,
 {
     GError *error = NULL;
 
-    egg_screen_execute_command_line_async (
-		gtk_widget_get_screen (cd->panel.applet), "gnome-cd", &error);
+    gdk_spawn_command_line_on_screen (
+		    		gtk_widget_get_screen (GTK_WIDGET (cd->panel.applet)),
+				"gnome-cd", &error);
+
     if (error) {
 	GtkWidget *dialog;
 
@@ -601,6 +603,9 @@ about_cb (BonoboUIComponent *component,
     const gchar *translator_credits = _("translator_credits");
 
     if (cd->about_dialog) {
+	gtk_window_set_screen (GTK_WINDOW (cd->about_dialog),
+			       gtk_widget_get_screen (cd->panel.applet));
+
 	gtk_window_present (GTK_WINDOW (cd->about_dialog));
         return;
     }
