@@ -1,6 +1,7 @@
 /* charpick.h -- header file for character picker applet */
 
 #include <gnome.h>
+#include <gconf/gconf-client.h>
 #include <panel-applet.h>
 #include <panel-applet-gconf.h>
 
@@ -20,8 +21,11 @@ struct _charpick_data {
   gint panel_size;
   gboolean panel_vertical;
   GtkWidget *propwindow;
+  GtkWidget *about_dialog;
   GtkWidget *pref_tree;
   GtkWidget *menu;
+  GtkWidget *add_edit_dialog;
+  GtkWidget *add_edit_entry;
 };
 
 
@@ -43,8 +47,12 @@ void save_chartable (charpick_data *curr_data);
 void show_preferences_dialog  (BonoboUIComponent *uic,
 			       charpick_data     *curr_data,
 			       const char        *verbname);
-gchar *run_edit_dialog  (gchar *string, gchar *title);
+
+void add_edit_dialog_create (charpick_data	 *curr_data,
+			     gchar		 *string,
+			     gchar		 *title);
 void set_atk_name_description (GtkWidget         *widget,
 			       const char        *name,
 			       const char        *description);
+gboolean key_writable (PanelApplet *applet, const char *key);
 
