@@ -37,6 +37,9 @@
 
 #define GROUPS_SUBMENU_PATH "/popups/popup/groups"
 
+static gboolean terminatedOnce = FALSE;
+static GSwitchItApplet *theAppletInstance = NULL;
+
 static void GSwitchItAppletCmdProps (BonoboUIComponent * uic,
 				     GSwitchItApplet * sia,
 				     const gchar * verb);
@@ -75,7 +78,8 @@ static void GSwitchItAppletCleanupNotebook (GSwitchItApplet * sia);
 
 static gboolean GSwitchItAppletButtonPressed (GtkWidget * widget,
 					      GdkEventButton * event,
-					      GSwitchItAppletConfig * config);
+					      GSwitchItAppletConfig *
+					      config);
 
 static gboolean GSwitchItAppletKeyPressed (GtkWidget * widget,
 					   GdkEventKey * event,
@@ -192,45 +196,26 @@ GSwitchItAppletFilterXEvt (GdkXEvent * xev,
 {
 	XEvent *xevent = (XEvent *) xev;
 	Display *display = xevent->xany.display;
-	int ignoredByXkl = XklFilterEvents (xevent);
-/**
- * WM_PROTOCOLS are handled in a special way - 
- * otherwize gtk drives CPU crazy.
- * We do it manually - because gdk_add_client_message_filter calls only
- * one filter per atom :(
- **/
-	switch (xevent->type) {
-	case ClientMessage:
+	XklFilterEvents (xevent);
+	switch ( xevent->type )
+	{
+		case ReparentNotify:
 		{
-			Atom message_type = xevent->xclient.message_type;
-			if (XInternAtom (display, "WM_PROTOCOLS", FALSE)
-			    == message_type
-			    && (GDK_FILTER_REMOVE ==
-				GSwitchItAppletWmProtocolsFilter (xev,
-								  event,
-								  sia)))
-				return GDK_FILTER_REMOVE;
-		}
-		break;
-	case ReparentNotify:
-		{
-			XReparentEvent *rne = (XReparentEvent *) xev;
+			XReparentEvent *rne = ( XReparentEvent * ) xev;
 			GtkWidget *w1;
 			GdkWindow *w;
-			w1 = gtk_widget_get_ancestor (sia->applet,
-						      GTK_TYPE_WINDOW);
-			if (w1 == NULL)
-				return GDK_FILTER_CONTINUE;
+			w1 = gtk_widget_get_ancestor( sia->applet, GTK_TYPE_WINDOW );
+			if( w1 == NULL )
+				break;
 			w = w1->window;
-			if (w == NULL || GDK_WINDOW_XID (w) != rne->window)
-				return GDK_FILTER_CONTINUE;
-			XklSetTransparent (GDK_WINDOW_XID (w), TRUE);
-			return GDK_FILTER_CONTINUE;
+			if( w == NULL || GDK_WINDOW_XID( w ) != rne->window )
+				break;
+			XklSetTransparent( GDK_WINDOW_XID( w ), TRUE );
 		}
 		break;
 	}
 
-	return ignoredByXkl ? GDK_FILTER_CONTINUE : GDK_FILTER_REMOVE;
+	return GDK_FILTER_CONTINUE;
 }
 
 GdkFilterReturn
@@ -312,10 +297,11 @@ GSwitchItAppletPrepareDrawing (GSwitchItApplet * sia, int group)
 					     GDK_INTERP_HYPER);
 		groupDrawingArea = gtk_image_new_from_pixbuf (scaled);
 		g_object_unref (G_OBJECT (scaled));
+		sia->ebox = NULL;	// not used in this case!
 	} else {
 		char *layoutName;
 		XklConfigItem configItem;
-		GtkWidget *align, *label, *ebox;
+		GtkWidget *align, *label;
 
 		if (XklMultipleLayoutsSupported ()) {
 			char *fullLayoutName =
@@ -324,7 +310,7 @@ GSwitchItAppletPrepareDrawing (GSwitchItApplet * sia, int group)
 			char *variantName;
 			if (!GSwitchItConfigSplitItems
 			    (fullLayoutName, &layoutName, &variantName))
-			    /* just in case */
+				/* just in case */
 				layoutName = fullLayoutName;
 
 			g_snprintf (configItem.name,
@@ -340,20 +326,21 @@ GSwitchItAppletPrepareDrawing (GSwitchItApplet * sia, int group)
 			layoutName = sia->groupNames[group];
 		align = gtk_alignment_new (0.5, 0.5, 1.0, 1.0);
 		label = gtk_label_new (layoutName);
-		ebox = gtk_event_box_new ();
-		groupDrawingArea = ebox;
-		g_signal_connect (G_OBJECT (ebox),
+		sia->ebox = gtk_event_box_new ();
+		groupDrawingArea = sia->ebox;
+		g_signal_connect (G_OBJECT (sia->ebox),
 				  "button_press_event",
 				  G_CALLBACK
 				  (GSwitchItAppletButtonPressed), sia);
 
-		g_signal_connect (G_OBJECT (sia->applet), 
+		g_signal_connect (G_OBJECT (sia->applet),
 				  "key_press_event",
-				  G_CALLBACK 
+				  G_CALLBACK
 				  (GSwitchItAppletKeyPressed), sia);
 
-		gtk_container_add (GTK_CONTAINER (ebox), align); 
 		gtk_container_add (GTK_CONTAINER (align), label);
+		gtk_container_add (GTK_CONTAINER (sia->ebox), align);
+
 		gtk_container_set_border_width (GTK_CONTAINER (align), 2);
 	}
 	return groupDrawingArea;
@@ -415,6 +402,50 @@ GSwitchItAppletChangePixelSize (PanelApplet *
 	GSwitchItAppletRevalidate (sia);
 }
 
+static void
+GSwitchItAppletChangeBackground (PanelApplet *
+				 widget, PanelAppletBackgroundType type,
+				 GdkColor * color, GdkPixmap * pixmap,
+				 GSwitchItApplet * sia)
+{
+	GtkRcStyle *rc_style = gtk_rc_style_new ();
+
+	switch (type) {
+	case PANEL_PIXMAP_BACKGROUND:
+		if (sia->ebox != NULL)
+			gtk_widget_modify_style (GTK_WIDGET (sia->ebox),
+						 rc_style);
+		gtk_widget_modify_style (GTK_WIDGET (sia->applet),
+					 rc_style);
+		break;
+
+	case PANEL_COLOR_BACKGROUND:
+		if (sia->ebox != NULL)
+			gtk_widget_modify_bg (GTK_WIDGET (sia->ebox),
+					      GTK_STATE_NORMAL, color);
+		gtk_widget_modify_bg (GTK_WIDGET (sia->applet),
+				      GTK_STATE_NORMAL, color);
+		break;
+
+	case PANEL_NO_BACKGROUND:
+		if (sia->ebox != NULL)
+			gtk_widget_modify_style (GTK_WIDGET (sia->ebox),
+						 rc_style);
+		gtk_widget_modify_style (GTK_WIDGET (sia->applet),
+					 rc_style);
+		break;
+
+	default:
+		if (sia->ebox != NULL)
+			gtk_widget_modify_style (GTK_WIDGET (sia->ebox),
+						 rc_style);
+		gtk_widget_modify_style (GTK_WIDGET (sia->applet),
+					 rc_style);
+		break;
+	}
+
+	gtk_rc_style_unref (rc_style);
+}
 
 static gboolean
 GSwitchItAppletKeyPressed (GtkWidget *
@@ -422,8 +453,7 @@ GSwitchItAppletKeyPressed (GtkWidget *
 			   GdkEventKey *
 			   event, GSwitchItAppletConfig * config)
 {
-	switch (event->keyval)
-	{
+	switch (event->keyval) {
 	case GDK_KP_Enter:
 	case GDK_ISO_Enter:
 	case GDK_3270_Enter:
@@ -458,8 +488,10 @@ GSwitchItAppletCmdProps (BonoboUIComponent *
 	/* Only one preferences window at a time */
 	if (sia->propsDialog) {
 		gtk_window_set_screen (GTK_WINDOW (sia->propsDialog),
-				       gtk_widget_get_screen (GTK_WIDGET (sia->applet)));
-		
+				       gtk_widget_get_screen (GTK_WIDGET
+							      (sia->
+							       applet)));
+
 		gtk_window_present (GTK_WINDOW (sia->propsDialog));
 		return;
 	}
@@ -468,19 +500,37 @@ GSwitchItAppletCmdProps (BonoboUIComponent *
 }
 
 void
-GSwitchItAppletCmdCapplet(BonoboUIComponent *
+GSwitchItAppletCmdCapplet (BonoboUIComponent *
 			   uic, GSwitchItApplet * sia, const gchar * verb)
 {
-	egg_screen_execute_shell (gtk_widget_get_screen (GTK_WIDGET (sia->applet)),
-				  NULL, "gnome-keyboard-properties");
+	GError *error = NULL;
+
+	gdk_spawn_command_line_on_screen (gtk_widget_get_screen
+					  (GTK_WIDGET (sia->applet)),
+					  "gnome-keyboard-properties",
+					  &error);
+
+	if (error != NULL) {
+		/* FIXME: After string ui freeze are over, we want to show an error message here */
+		g_error_free (error);
+	}
 }
 
 void
 GSwitchItAppletCmdPlugins (BonoboUIComponent *
 			   uic, GSwitchItApplet * sia, const gchar * verb)
 {
- 	egg_screen_execute_shell (gtk_widget_get_screen (GTK_WIDGET (sia->applet)),
-				  NULL, "gswitchit-plugins-capplet");
+	GError *error = NULL;
+
+	gdk_spawn_command_line_on_screen (gtk_widget_get_screen
+					  (GTK_WIDGET (sia->applet)),
+					  "gswitchit-plugins-capplet",
+					  &error);
+
+	if (error != NULL) {
+		/* FIXME: after string ui freeze are over, we want to show an error message here */
+		g_error_free (error);
+	}
 }
 
 static void
@@ -535,8 +585,10 @@ GSwitchItAppletCmdAbout (BonoboUIComponent *
 	gchar *file;
 	if (sia->aboutDialog) {
 		gtk_window_set_screen (GTK_WINDOW (sia->aboutDialog),
-				       gtk_widget_get_screen (GTK_WIDGET (sia->applet)));
-		
+				       gtk_widget_get_screen (GTK_WIDGET
+							      (sia->
+							       applet)));
+
 		gtk_window_present (GTK_WINDOW (sia->aboutDialog));
 		return;
 	}
@@ -566,8 +618,9 @@ GSwitchItAppletCmdAbout (BonoboUIComponent *
 	g_free (file);
 
 	gtk_window_set_screen (GTK_WINDOW (sia->aboutDialog),
-			       gtk_widget_get_screen (GTK_WIDGET (sia->applet)));
-	
+			       gtk_widget_get_screen (GTK_WIDGET
+						      (sia->applet)));
+
 	gtk_window_present (GTK_WINDOW (sia->aboutDialog));
 }
 
@@ -758,6 +811,10 @@ GSwitchItAppletInit (GSwitchItApplet * sia, PanelApplet * applet)
 	g_signal_connect (G_OBJECT (sia->applet), "change_size",
 			  G_CALLBACK (GSwitchItAppletChangePixelSize),
 			  sia);
+	g_signal_connect (G_OBJECT (sia->applet), "change_background",
+			  G_CALLBACK (GSwitchItAppletChangeBackground),
+			  sia);
+
 	GSwitchItAppletStartListen (sia);
 	gtk_widget_add_events (sia->applet, GDK_BUTTON_PRESS_MASK);
 
@@ -771,7 +828,6 @@ GSwitchItAppletInit (GSwitchItApplet * sia, PanelApplet * applet)
 void
 GSwitchItAppletTerm (PanelApplet * applet, GSwitchItApplet * sia)
 {
-	static gboolean terminatedOnce = FALSE;
 	if (terminatedOnce) {
 		XklDebug (0,
 			  "Please do not call the termination method twice!!!\n");
@@ -795,28 +851,30 @@ GSwitchItAppletTerm (PanelApplet * applet, GSwitchItApplet * sia)
 	XklConfigTerm ();
 	XklTerm ();
 
+	terminatedOnce = TRUE;
+	g_free (theAppletInstance);
+	theAppletInstance = NULL;
 	XklDebug (100, "The applet successfully terminated\n");
 }
 
 gboolean
 GSwitchItAppletNew (PanelApplet * applet)
 {
-	static GSwitchItApplet *sia = NULL;
 	gboolean rv = TRUE;
 #if 0
 	GLogLevelFlags fatal_mask;
 	fatal_mask = G_LOG_LEVEL_WARNING | G_LOG_LEVEL_CRITICAL;
 	g_log_set_always_fatal (fatal_mask);
 #endif
-	/* BASTARDS! THEY CALL THIS METHOD TWICE!!! */
-	if (sia == NULL) {
-		sia = g_new0 (GSwitchItApplet, 1);
-		rv = GSwitchItAppletInit (sia, applet);
+	if (theAppletInstance == NULL) {
+		terminatedOnce = FALSE;
+		theAppletInstance = g_new0 (GSwitchItApplet, 1);
+		rv = GSwitchItAppletInit (theAppletInstance, applet);
 		XklDebug (100, "The applet successfully started: %d\n",
 			  rv);
-	}
-	XklDebug (0,
-		  "Please do not call the initialization method twice!!!\n");
+	} else
+		XklDebug (0,
+			  "Please do not call the initialization method twice!!!\n");
 	return rv;
 }
 
