@@ -1,4 +1,4 @@
-/* $Id: gweather-about.c,v 1.12 2003/02/21 00:48:23 kevinv Exp $ */
+/* $Id: gweather-about.c,v 1.17 2004/02/23 05:24:18 dsmit Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -26,9 +26,9 @@
 
 void gweather_about_run (GWeatherApplet *gw_applet)
 {
-    GdkPixbuf   *pixbuf;
+    GtkIconInfo *icon_info;
+    GdkPixbuf   *pixbuf = NULL;
     GError	*error = NULL;
-    gchar	*file;
     
     static const gchar *authors[] = {
 	"Kevin Vandersloot <kfv101@psu.edu>",
@@ -38,30 +38,34 @@ void gweather_about_run (GWeatherApplet *gw_applet)
     };
 
     const gchar *documenters[] = {
+        "Dan Mueth <d-mueth@uchicago.edu>",
+        "Spiros Papadimitriou <spapadim+@cs.cmu.edu>",
+	"Sun GNOME Documentation Team <gdocteam@sun.com>",
 	NULL
     };
 
     const gchar *translator_credits = _("translator_credits");
 
-    static GtkWidget *about_dialog = NULL;
     
-    if (about_dialog) {
-	gtk_window_set_screen (GTK_WINDOW (about_dialog),
+    if (gw_applet->about_dialog) {
+	gtk_window_set_screen (GTK_WINDOW (gw_applet->about_dialog),
 			       gtk_widget_get_screen (GTK_WIDGET (gw_applet->applet)));
-	gtk_window_present (GTK_WINDOW (about_dialog));
+
+	gtk_window_present (GTK_WINDOW (gw_applet->about_dialog));
 	return;
     }
     
-    file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "gweather/tstorm.xpm", FALSE, NULL);
-    pixbuf = gdk_pixbuf_new_from_file (file, &error);
-    g_free (file);
-    
-    if (error) {
-    	g_warning (G_STRLOC ": cannot open %s: %s", file, error->message);
-	g_error_free (error);
+    icon_info = gtk_icon_theme_lookup_icon (gtk_icon_theme_get_default (), "stock_weather-storm", 48, 0);
+    if (icon_info) {
+        pixbuf = gtk_icon_info_load_icon (icon_info, &error);
+
+        if (error) {
+    	    g_warning (G_STRLOC ": cannot open %s: %s", gtk_icon_info_get_filename (icon_info), error->message);
+	    g_error_free (error);
+        }
     }
     
-    about_dialog = gnome_about_new (_("Weather Report"), VERSION,
+    gw_applet->about_dialog = gnome_about_new (_("Weather Report"), VERSION,
                                     _("Copyright (c)1999 by S. Papadimitriou"),
                                     _("Released under the GNU General Public License.\n\n"
                                     	"An applet for monitoring local weather conditions."),
@@ -72,14 +76,17 @@ void gweather_about_run (GWeatherApplet *gw_applet)
     if (pixbuf)
     	gdk_pixbuf_unref (pixbuf);
 
-    gtk_window_set_screen (GTK_WINDOW (about_dialog),
-			   gtk_widget_get_screen (GTK_WIDGET (gw_applet->applet)));
-    gtk_window_set_wmclass (GTK_WINDOW (about_dialog), "weather report", "Weather Report");	
-    gnome_window_icon_set_from_file (GTK_WINDOW (about_dialog), GNOME_ICONDIR"/gweather/tstorm.xpm");	
+    gtk_window_set_screen (GTK_WINDOW (gw_applet->about_dialog),
+ 			   gtk_widget_get_screen (GTK_WIDGET (gw_applet->applet)));                            
+    gtk_window_set_wmclass (GTK_WINDOW (gw_applet->about_dialog), "weather report", "Weather Report");	
+    gnome_window_icon_set_from_file (GTK_WINDOW (gw_applet->about_dialog), gtk_icon_info_get_filename (icon_info));	
     
-    gtk_signal_connect( GTK_OBJECT(about_dialog), "destroy",
-		        GTK_SIGNAL_FUNC(gtk_widget_destroyed), &about_dialog );
-    gtk_widget_show(about_dialog);
+    gtk_signal_connect (GTK_OBJECT (gw_applet->about_dialog), "destroy",
+		        GTK_SIGNAL_FUNC(gtk_widget_destroyed), &gw_applet->about_dialog );
+    gtk_widget_show (gw_applet->about_dialog);
+    
+    if (icon_info)
+        gtk_icon_info_free (icon_info);
     
     return;
 }
