@@ -13,59 +13,46 @@
 
 #include <gnome.h>
 #include <panel-applet.h>
-#include <libgnomevfs/gnome-vfs.h>
+
+
+
+/* Radar map on by default. */
+#define RADARMAP
 
 G_BEGIN_DECLS
  
 typedef struct _GWeatherApplet GWeatherApplet;
 typedef struct _GWeatherPrefs GWeatherPrefs;
-typedef struct _WeatherForecast WeatherForecast;
 typedef struct _WeatherInfo WeatherInfo;
 typedef struct _WeatherLocation WeatherLocation;
 
-#define MAX_FORECASTS 5
-
 struct _GWeatherPrefs {
     WeatherLocation *location;
     gint update_interval;  /* in seconds */
     gboolean update_enabled;
     gboolean use_metric;
     gboolean detailed;
-    gchar *city;
-    gchar *url;
-    gboolean show_labels;
+    gboolean radar_enabled;
+    gboolean use_custom_radar_url;
+    gchar *radar;
 };
 
 struct _GWeatherApplet
 {
 	PanelApplet *applet;
 	WeatherInfo *gweather_info;
-	
+
+	GtkWidget *container;
 	GtkWidget *box;	
 	GtkWidget *label;
 	GtkWidget *image;
-	GtkWidget *images[MAX_FORECASTS+1];
-    	GtkWidget *boxes[MAX_FORECASTS+1];
-	GtkWidget *labels[MAX_FORECASTS+1];
-	GtkWidget *events[MAX_FORECASTS+1];
 	GtkTooltips *tooltips;
 	
 	PanelAppletOrient orient;
 	gint size;
 	gint timeout_tag;
-	gint animation_tag;
-	gint animation_loc;
 
-	/* Locations stuff */
-	GnomeVFSAsyncHandle *locations_handle;
-	gchar *locations_xml;
-	GtkTreeStore *country_model;
-	GtkWidget *country_tree;
-	GtkTreeStore *city_model;
-	GtkWidget *city_tree;
-	GtkWidget *druid;
-	GtkTreeIter country_iter;
-	gint fetchid; /*-1 not fetching, 0 county, 1 cities */
+	GtkWidget *about_dialog;
 	
 	/* preferences  */
 	GWeatherPrefs gweather_pref;
@@ -74,9 +61,14 @@ struct _GWeatherApplet
 
 	GtkWidget *pref_basic_metric_btn;
 	GtkWidget *pref_basic_detailed_btn;
+#ifdef RADARMAP
+	GtkWidget *pref_basic_radar_btn;
+	GtkWidget *pref_basic_radar_url_btn;
+	GtkWidget *pref_basic_radar_url_hbox;
+	GtkWidget *pref_basic_radar_url_entry;
+#endif /* RADARMAP */
 	GtkWidget *pref_basic_update_spin;
 	GtkWidget *pref_basic_update_btn;
-	GtkWidget *pref_location_city_label;
 	GtkWidget *pref_tree;
 	
 	/* dialog stuff */
@@ -93,16 +85,15 @@ struct _GWeatherApplet
 	GtkWidget *cond_pressure;
 	GtkWidget *cond_vis;
 	GtkWidget *cond_image;
-	GtkWidget *cond_feeltemp;
 	GtkWidget *forecast_text;
 	GtkWidget *radar_image;
-	GtkWidget *forecast_tree;
-	GtkTreeModel *forecast_model;
 
+	GdkPixbuf *dialog_pixbuf;
+	GdkBitmap *dialog_mask;
+	GdkPixbuf *applet_pixbuf;
+	GdkBitmap *applet_mask;
 };
 
-void update_display (GWeatherApplet *applet);
-
 G_END_DECLS
  
 #endif
