@@ -1,4 +1,4 @@
-/* $Id: weather.c,v 1.72 2004/03/05 09:55:31 dsmit Exp $ */
+/* $Id: weather.c,v 1.75 2004/04/25 18:19:33 kevinv Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -298,7 +298,7 @@ close_cb (GnomeVFSAsyncHandle *handle, GnomeVFSResult result, gpointer data)
 #define TIME_RE_STR  "^([0-9]{6})Z$"
 #define WIND_RE_STR  "^(([0-9]{3})|VRB)([0-9]?[0-9]{2})(G[0-9]?[0-9]{2})?KT$"
 #define VIS_RE_STR   "^(([0-9]?[0-9])|(M?1/[0-9]?[0-9]))SM$"
-#define CLOUD_RE_STR "^(CLR|BKN|SCT|FEW|OVC)([0-9]{3})?$"
+#define CLOUD_RE_STR "^(CLR|BKN|SCT|FEW|OVC|SKC)([0-9]{3})?$"
 #define TEMP_RE_STR  "^(M?[0-9][0-9])/(M?(//|[0-9][0-9]))$"
 #define PRES_RE_STR  "^(A|Q)([0-9]{4})$"
 #define COND_RE_STR  "^(-|\\+)?(VC|MI|BC|PR|TS|BL|SH|DR|FZ)?(DZ|RA|SN|SG|IC|PE|GR|GS|UP|BR|FG|FU|VA|SA|HZ|PY|DU|SQ|SS|DS|PO|\\+?FC)$"
@@ -526,7 +526,13 @@ static gboolean metar_tok_cloud (gchar *tokp, WeatherInfo *info)
     gint alt = -1;
 
     if (regexec(&metar_re[CLOUD_RE], tokp, 0, NULL, 0) == REG_NOMATCH)
-        return FALSE;
+	if (!strcmp(tokp,"CAVOK"))
+	{
+		info->sky=SKY_CLEAR;
+		return TRUE;
+	}
+   	else
+        	return FALSE;
 
     strncpy(stype, tokp, 3);
     stype[3] = 0;
@@ -538,6 +544,8 @@ static gboolean metar_tok_cloud (gchar *tokp, WeatherInfo *info)
 
     if (!strcmp(stype, "CLR")) {
         info->sky = SKY_CLEAR;
+    } else if (!strcmp(stype, "SKC")) {
+        info->sky = SKY_CLEAR;
     } else if (!strcmp(stype, "BKN")) {
         info->sky = SKY_BROKEN;
     } else if (!strcmp(stype, "SCT")) {
@@ -1995,7 +2003,7 @@ const gchar *weather_info_get_humidity (WeatherInfo *info)
 
 const gchar *weather_info_get_wind (WeatherInfo *info)
 {
-    static gchar buf[100];
+    static gchar buf[200];
     g_return_val_if_fail(info != NULL, NULL);
     if (!info->valid)
         return "-";
@@ -2013,7 +2021,7 @@ const gchar *weather_info_get_wind (WeatherInfo *info)
 
 const gchar *weather_info_get_pressure (WeatherInfo *info)
 {
-    static gchar buf[30];
+    static gchar buf[100];
     g_return_val_if_fail(info != NULL, NULL);
     if (!info->valid)
         return "-";
@@ -2025,7 +2033,7 @@ const gchar *weather_info_get_pressure (WeatherInfo *info)
 
 const gchar *weather_info_get_visibility (WeatherInfo *info)
 {
-    static gchar buf[40];
+    static gchar buf[100];
     g_return_val_if_fail(info != NULL, NULL);
     if (!info->valid)
         return "-";
