@@ -60,6 +60,9 @@ about_cb (BonoboUIComponent *uic,
     const gchar *translator_credits = _("translator_credits");
 
     if (ma->about_dialog) {
+	gtk_window_set_screen (GTK_WINDOW (ma->about_dialog),
+			       gtk_widget_get_screen (GTK_WIDGET (ma->applet)));
+
 	gtk_window_present (GTK_WINDOW (ma->about_dialog));
 	return;
     }
@@ -106,7 +109,7 @@ help_cb (BonoboUIComponent *uic,
                                                                                 
     	egg_help_display_on_screen (
                 "multiload", NULL,
-                gtk_widget_get_screen (ma->applet),
+                gtk_widget_get_screen (GTK_WIDGET (ma->applet)),
                 &error);
                                                                                 
     	if (error) { /* FIXME: the user needs to see this */
@@ -126,10 +129,11 @@ start_procman (MultiloadApplet *ma)
 	GError *error = NULL;
 
 	g_return_if_fail (ma != NULL);
-	
-	egg_screen_execute_command_line_async (
+
+	gdk_spawn_command_line_on_screen (
 			gtk_widget_get_screen (GTK_WIDGET (ma->applet)),
 			"gnome-system-monitor", &error);
+
 	if (error) {
 		GtkWidget *dialog;
 
@@ -182,12 +186,41 @@ multiload_change_orient_cb(PanelApplet *applet, gint arg1, gpointer data)
 	return;
 }
 
+void
+multiload_change_background_cb(PanelApplet *a, PanelAppletBackgroundType type,
+				GdkColor *color, GdkPixmap *pixmap,
+				gpointer *data)
+{
+	MultiloadApplet *ma = data;
+	GtkRcStyle *rc_style = gtk_rc_style_new ();
+
+	switch (type) {
+		case PANEL_PIXMAP_BACKGROUND:
+			gtk_widget_modify_style (GTK_WIDGET (ma->applet), rc_style);
+			break;
+
+		case PANEL_COLOR_BACKGROUND:
+			gtk_widget_modify_bg (GTK_WIDGET (ma->applet), GTK_STATE_NORMAL, color);
+			break;
+
+		case PANEL_NO_BACKGROUND:
+			gtk_widget_modify_style (GTK_WIDGET (ma->applet), rc_style);
+			break;
+
+		default:
+			gtk_widget_modify_style (GTK_WIDGET (ma->applet), rc_style);
+			break;
+	}
+
+	gtk_rc_style_unref (rc_style);
+}
+
 void
 multiload_destroy_cb(GtkWidget *widget, gpointer data)
 {
 	gint i;
 	MultiloadApplet *ma = data;
-	
+
 	for (i = 0; i < NGRAPHS; i++)
 	{
 		if (ma->graphs[i]->visible)
@@ -205,8 +238,13 @@ multiload_destroy_cb(GtkWidget *widget, gpointer data)
 	if (ma->about_dialog)
 		gtk_widget_destroy (ma->about_dialog);
 	
+	if (ma->prop_dialog)
+		gtk_widget_destroy (ma->prop_dialog);
+
 	gtk_widget_destroy(GTK_WIDGET(ma->applet));
-			
+
+	g_free (ma);
+
 	return;
 }
 
@@ -409,7 +447,8 @@ multiload_applet_new(PanelApplet *applet, const gchar *iid, gpointer data)
 	ma->applet = applet;
 	
 	ma->about_dialog = NULL;
-	
+	ma->prop_dialog = NULL;
+
 	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-monitor.png");
 	
 	panel_applet_add_preferences (applet, "/schemas/apps/multiload/prefs", NULL);
@@ -446,6 +485,8 @@ multiload_applet_new(PanelApplet *applet, const gchar *iid, gpointer data)
 				G_CALLBACK(multiload_change_size_cb), ma);
 	g_signal_connect(G_OBJECT(applet), "change_orient",
 				G_CALLBACK(multiload_change_orient_cb), ma);
+	g_signal_connect(G_OBJECT(applet), "change_background",
+				G_CALLBACK(multiload_change_background_cb), ma);
 	g_signal_connect(G_OBJECT(applet), "destroy",
 				G_CALLBACK(multiload_destroy_cb), ma);
 	g_signal_connect(G_OBJECT(applet), "enter_notify_event",
