@@ -116,6 +116,7 @@ void stickynotes_applet_init(PanelApplet *panel_applet)
 {	
 	GnomeIconTheme *icon_theme;
 	gchar *sticky_icon;
+	GnomeClient *client;
 
 	stickynotes = g_new(StickyNotes, 1);
 
@@ -148,6 +149,13 @@ void stickynotes_applet_init(PanelApplet *panel_applet)
 	gconf_client_add_dir(stickynotes->gconf, GCONF_PATH, GCONF_CLIENT_PRELOAD_NONE, NULL);
 	gconf_client_notify_add(stickynotes->gconf, GCONF_PATH "/defaults", (GConfClientNotifyFunc) preferences_apply_cb, NULL, NULL, NULL);
 	gconf_client_notify_add(stickynotes->gconf, GCONF_PATH "/settings", (GConfClientNotifyFunc) preferences_apply_cb, NULL, NULL, NULL);
+
+	client = gnome_master_client ();
+	gnome_client_set_restart_style (client, GNOME_RESTART_NEVER);
+
+	/* The help suggests this is automatic, but that seems to not be the case here. */
+	gnome_client_connect (client);
+	gnome_client_flush (client);
 	
 	/* Load sticky notes */
 	stickynotes_load(gtk_widget_get_screen(GTK_WIDGET(panel_applet)));
@@ -263,6 +271,7 @@ StickyNotesApplet * stickynotes_applet_new(PanelApplet *panel_applet)
 	applet->w_applet = GTK_WIDGET(panel_applet);
 	applet->w_image = gtk_image_new();
 	applet->about_dialog = NULL;
+	applet->destroy_all_dialog = NULL;
 	applet->prelighted = FALSE;
 	applet->pressed = FALSE;
 
@@ -337,20 +346,26 @@ void stickynotes_applet_update_icon(StickyNotesApplet *applet)
 
 void stickynotes_applet_update_prefs()
 {
+	gint height, click_behavior;
+	gboolean sys_color, sys_font, sticky, force_default;
+	gchar *font_str;
+	GdkColor color;
 	gint width = gconf_client_get_int(stickynotes->gconf, GCONF_PATH "/defaults/width", NULL);
+
 	width = MAX (width, 1);
-	gint height = gconf_client_get_int(stickynotes->gconf, GCONF_PATH "/defaults/height", NULL);
+	height = gconf_client_get_int(stickynotes->gconf, GCONF_PATH "/defaults/height", NULL);
 	height = MAX (height, 1);
-	gboolean sys_color = gconf_client_get_bool(stickynotes->gconf, GCONF_PATH "/settings/use_system_color", NULL);
-	gboolean sys_font = gconf_client_get_bool(stickynotes->gconf, GCONF_PATH "/settings/use_system_font", NULL);
-	gint click_behavior = gconf_client_get_int(stickynotes->gconf, GCONF_PATH "/settings/click_behavior", NULL);
-	gboolean sticky = gconf_client_get_bool(stickynotes->gconf, GCONF_PATH "/settings/sticky", NULL);
-	gboolean force_default = gconf_client_get_bool(stickynotes->gconf, GCONF_PATH "/settings/force_default", NULL);
-	gchar *font_str = gconf_client_get_string(stickynotes->gconf, GCONF_PATH "/defaults/font", NULL);
+
+	sys_color = gconf_client_get_bool(stickynotes->gconf, GCONF_PATH "/settings/use_system_color", NULL);
+	sys_font = gconf_client_get_bool(stickynotes->gconf, GCONF_PATH "/settings/use_system_font", NULL);
+	click_behavior = gconf_client_get_int(stickynotes->gconf, GCONF_PATH "/settings/click_behavior", NULL);
+	sticky = gconf_client_get_bool(stickynotes->gconf, GCONF_PATH "/settings/sticky", NULL);
+	force_default = gconf_client_get_bool(stickynotes->gconf, GCONF_PATH "/settings/force_default", NULL);
+	font_str = gconf_client_get_string(stickynotes->gconf, GCONF_PATH "/defaults/font", NULL);
+
 	if (!font_str)
 		font_str = g_strdup ("Sans 10");
 	
-	GdkColor color;
 	{
 		gchar *color_str = gconf_client_get_string(stickynotes->gconf, GCONF_PATH "/defaults/color", NULL);
 		if (!color_str)
