@@ -31,6 +31,7 @@ gboolean applet_save_cb(StickyNotesApplet *applet);
 gboolean applet_change_size_cb(GtkWidget *widget, gint size, StickyNotesApplet *applet);
 gboolean applet_change_bg_cb(PanelApplet *panel_applet, PanelAppletBackgroundType type, GdkColor *color, GdkPixmap *pixmap,
 			     StickyNotesApplet *applet);
+void applet_destroy_cb (PanelApplet *panel_applet, StickyNotesApplet *applet);
 
 /* Callbacks for sticky notes applet menu */
 void menu_create_cb(BonoboUIComponent *uic, StickyNotesApplet *applet, const gchar *verbname);
@@ -47,8 +48,6 @@ void preferences_color_cb(GnomeColorPicker *cp, guint r, guint g, guint b, guint
 void preferences_font_cb(GnomeFontPicker *fp, gchar *font_str, gpointer data);
 void preferences_apply_cb(GConfClient *client, guint cnxn_id, GConfEntry *entry, gpointer data);
 void preferences_response_cb(GtkDialog *dialog, gint response, gpointer data);
-
-/* Callbacks for sticky notes about dialog */
-void about_response_cb(GtkDialog *dialog, gint response, gpointer data);
+gboolean preferences_delete_cb(GtkWidget *widget, GdkEvent *event, gpointer data);
 
 #endif /* __STICKYNOTES_APPLET_CALLBACKS_H__ */
