@@ -75,6 +75,7 @@ typedef struct {
 	GtkWidget *pct_label;
 	GtkWidget *pixmap;
 	GtkWidget *box;
+	GtkWidget *about_dialog;
 	guint timeout_handler_id;
 	FILE *file;
 	GtkTooltips *tips;
@@ -125,6 +126,12 @@ wireless_applet_get_type (void)
 	return type;
 }
 
+/* FIXME: The icon used by this applet when there's no signal is impossible
+ * to localise as it says N/A in the icon itself. Need to swap the icon
+ * with something more l10n friendly. Also, localising the label makes it
+ * necessary to ditch g_strcasecmp() in favor of something else.
+ */
+
 static void 
 wireless_applet_draw (WirelessApplet *applet, int percent)
 {
@@ -136,7 +143,7 @@ wireless_applet_draw (WirelessApplet *applet, int percent)
 	if (percent > 0) {
 		tmp = g_strdup_printf ("%2.0d%%", percent);
 	} else {
-		tmp = g_strdup_printf ("N/A");
+		tmp = g_strdup_printf (_("N/A"));
 	}
 
 	label_text = gtk_label_get_text (GTK_LABEL (applet->pct_label));
@@ -243,6 +250,7 @@ wireless_applet_read_device_state (WirelessApplet *applet)
 	double link;
 	char device[256];
 	char line[256];
+	gboolean found = FALSE;
 
 	/* resest list of available wireless devices */
 	g_list_foreach (applet->devices, (GFunc)g_free, NULL);
@@ -270,7 +278,7 @@ wireless_applet_read_device_state (WirelessApplet *applet)
 			applet->devices = g_list_prepend (applet->devices, g_strdup (device));
 
 			/* is it the one we're supposed to monitor ? */
-			if (g_strcasecmp (applet->device, device)==0) {
+			if (g_ascii_strcasecmp (applet->device, device)==0) {
 				link = strtod (ptr, &ptr);
 				ptr++;
 
@@ -281,6 +289,7 @@ wireless_applet_read_device_state (WirelessApplet *applet)
 				ptr++;
 
 				wireless_applet_update_state (applet, device, link, level, noise);
+				found = TRUE;
 			}
 		}
 	} while (1);
@@ -288,7 +297,7 @@ wireless_applet_read_device_state (WirelessApplet *applet)
 	if (g_list_length (applet->devices)==1) {
 		wireless_applet_set_device (applet,
 				(char*)applet->devices->data);
-	} else {
+	} else if (found == FALSE) {
 		wireless_applet_update_state (applet,
 				applet->device, -1, -1, -1);
 	}
@@ -548,21 +557,27 @@ wireless_applet_help_cb (BonoboUIComponent *uic, WirelessApplet *applet)
 static void
 wireless_applet_about_cb (BonoboUIComponent *uic, WirelessApplet *applet)
 {
-	static GtkWidget *about = NULL;
 	GdkPixbuf *pixbuf;
 	char *file;
+
 	const gchar *authors[] = {
 		"Eskil Heyn Olsen <eskil@eskil.org>",
 		"Bastien Nocera <hadess@hadess.net> (Gnome2 port)",
 		NULL
 	};
-	const gchar *documenters[] = { NULL };
+
+	const gchar *documenters[] = { 
+                 "Sun GNOME Documentation Team <gdocteam@sun.com>",
+ 	        NULL 
+         };	
+
 	const gchar *translator_credits = _("translator_credits");
 
-	if (about != NULL)
-	{
-		gtk_widget_show (about);
-		gtk_window_present (GTK_WINDOW (about));
+	if (applet->about_dialog != NULL) {
+		gtk_window_set_screen (GTK_WINDOW (applet->about_dialog),
+				       gtk_widget_get_screen (GTK_WIDGET (&applet->base)));
+		
+		gtk_window_present (GTK_WINDOW (applet->about_dialog));
 		return;
 	}
 
@@ -571,7 +586,7 @@ wireless_applet_about_cb (BonoboUIComponent *uic, WirelessApplet *applet)
 	pixbuf = gdk_pixbuf_new_from_file (file, NULL);
 	g_free (file);
 
-	about = gnome_about_new (
+	applet->about_dialog = gnome_about_new (
 			_("Wireless Link Monitor"),
 			VERSION,
 			_("(C) 2001, 2002 Free Software Foundation "),
@@ -582,11 +597,15 @@ wireless_applet_about_cb (BonoboUIComponent *uic, WirelessApplet *applet)
 			pixbuf);
 
 	g_object_unref (pixbuf);
-	
-	gtk_widget_show (about);
 
-	g_object_add_weak_pointer (G_OBJECT (about),
-			(void**)&about);
+	gtk_window_set_screen (GTK_WINDOW (applet->about_dialog),
+			       gtk_widget_get_screen (GTK_WIDGET (applet)));
+
+	g_signal_connect (applet->about_dialog, "destroy",
+			  G_CALLBACK (gtk_widget_destroyed),
+			  &applet->about_dialog);
+ 
+	gtk_widget_show (applet->about_dialog);
 
 	return;
 }
@@ -641,6 +660,11 @@ wireless_applet_destroy (WirelessApplet *applet, gpointer horse)
 	for (i = 0; i < PIX_NUMBER; i++)
 		g_object_unref (applet->pixmaps[i]);
 
+	if (applet->about_dialog) {
+		gtk_widget_destroy (applet->about_dialog);
+		applet->about_dialog = NULL;
+	}
+
 	if (applet->prefs) {
 		gtk_widget_destroy (applet->prefs);
 		applet->prefs = NULL;
@@ -717,6 +741,7 @@ setup_widgets (WirelessApplet *applet)
 	gtk_container_add (GTK_CONTAINER (applet), applet->box);
 
 	applet->current_pixbuf = NULL;
+	applet->about_dialog = NULL;
 }
 
 static void change_size_cb(PanelApplet *pa, gint s, WirelessApplet *applet)
@@ -731,6 +756,33 @@ static void change_orient_cb(PanelApplet *pa, gint s, WirelessApplet *applet)
 	wireless_applet_timeout_handler (applet);
 }
 
+static void change_background_cb(PanelApplet *a, PanelAppletBackgroundType type,
+				 GdkColor *color, GdkPixmap *pixmap,
+				 WirelessApplet *applet)
+{
+	GtkRcStyle *rc_style = gtk_rc_style_new ();
+
+	switch (type) {
+		case PANEL_PIXMAP_BACKGROUND:
+			gtk_widget_modify_style (GTK_WIDGET (applet), rc_style);
+			break;
+
+		case PANEL_COLOR_BACKGROUND:
+			gtk_widget_modify_bg (GTK_WIDGET (applet), GTK_STATE_NORMAL, color);
+			break;
+
+		case PANEL_NO_BACKGROUND:
+			gtk_widget_modify_style (GTK_WIDGET (applet), rc_style);
+			break;
+
+		default:
+			gtk_widget_modify_style (GTK_WIDGET (applet), rc_style);
+			break;
+	}
+
+	gtk_rc_style_unref (rc_style);
+}
+
 static GtkWidget *
 wireless_applet_new (WirelessApplet *applet)
 {
@@ -787,10 +839,12 @@ wireless_applet_new (WirelessApplet *applet)
 	}
 		 
 	g_signal_connect (G_OBJECT (applet), "change_size",
-				  G_CALLBACK (change_size_cb), applet);
+			  G_CALLBACK (change_size_cb), applet);
 	g_signal_connect (G_OBJECT (applet), "change_orient",
-				  G_CALLBACK (change_orient_cb), applet);
-  
+			  G_CALLBACK (change_orient_cb), applet);
+ 	g_signal_connect (G_OBJECT (applet), "change_background",
+			  G_CALLBACK (change_background_cb), applet);
+
 	return GTK_WIDGET (applet);
 }
 
